Documentation
¶
Overview ¶
Package ccgo translates C to Go source code.
This v1 package is obsolete. Please use current ccgo/v4:
The command ¶
https://github.com/next-bin/go-sqlite3/pkg/ccgo4
The library ¶
https://github.com/next-bin/go-sqlite3/pkg/ccgo4/lib
Index ¶
Constants ¶
This section is empty.
Variables ¶
var ( // Testing amends things for tests. Testing bool )
Functions ¶
Types ¶
type Option ¶
type Option func(*options) error
Option is a configuration/setup function that can be passed to the New function.
func LibcTypes ¶
func LibcTypes() Option
LibcTypes makes code refering to libc types import them from the CRT package.
Directories
¶
| Path | Synopsis |
|---|---|
|
Package crt provides C-runtime services.
|
Package crt provides C-runtime services. |
|
Package ccgo translates C to Go source code.
|
Package ccgo translates C to Go source code. |
|
ccgo
command
Command ccgo is a C compiler targeting Go.
|
Command ccgo is a C compiler targeting Go. |
|
internal/object
Package object reads and writes object files.
|
Package object reads and writes object files. |
Click to show internal directories.
Click to hide internal directories.