Documentation
¶
Overview ¶
Package file provides an os.File-like interface of a memory mapped file.
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type Interface ¶
type Interface interface {
io.ReaderAt
io.ReaderFrom
io.WriterAt
io.WriterTo
Close() error
Stat() (os.FileInfo, error)
Sync() error
Truncate(int64) error
}
Interface is a os.File-like entity.
func Open ¶
Open returns a new Interface backed by f, or an error, if any.
This function does not use memory mapped file I/O on Windows because there some methods, like Truncate, produce errors in the current implementation:
The requested operation cannot be performed on a file with a user-mapped section open.
Windows expert needed to fix this.
Click to show internal directories.
Click to hide internal directories.