Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
Types ¶
type Interface ¶
type Interface interface {
// Init initializes the scanner with src, which is assumed to come from name.
Init(name string, src []byte) error
// Rune returns any rune for class c and indicated if the class is valid.
Rune(c byte) (r rune, ok bool)
// Scan scans the source set by Init and returns and error if the source does
// not start with a valid token.
Scan() error
}
Interface wraps methods of the tested scanner/lexer/tokenizer.
Click to show internal directories.
Click to hide internal directories.